#
# spec file for package lswt
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           lswt
Version:        2.0.0
Release:        2.1
Summary:        Wayland toplevel lister
License:        GPL-3.0-only
Group:          System/X11/Utilities
URL:            https://git.sr.ht/~leon_plickat/lswt
Source:         https://git.sr.ht/~leon_plickat/lswt/archive/v2.0.0.tar.gz#/%{name}-%{version}.tar.gz
Patch0:         Makefile.patch
Patch1:         https://git.sr.ht/~leon_plickat/lswt/commit/ea45c1a8cf66d102e6525d29b03126693949e562.patch
Patch2:         https://git.sr.ht/~leon_plickat/lswt/commit/c1ea4ee2a6e4a4e579a17f1e15351f225cb23a1d.patch
Patch3:         https://git.sr.ht/~leon_plickat/lswt/commit/8d76a317ad2da073a638d72eac8a24df33ae01f1.patch
Patch4:         https://git.sr.ht/~leon_plickat/lswt/commit/fdf0932f2939696a8398b63871ccc85335274c1f.patch
Patch5:         https://git.sr.ht/~leon_plickat/lswt/commit/fbb7be4354508b41552ce2159b1203db123916ac.patch
Patch6:         https://git.sr.ht/~leon_plickat/lswt/commit/e4ebefcb30053a990cb821a75c4e1310fc967673.patch
Patch7:         https://git.sr.ht/~leon_plickat/lswt/commit/55a29650a110928cb7ad612182c8096424ebb70a.patch
Patch8:         https://git.sr.ht/~leon_plickat/lswt/commit/ade15dbc3d11325a2569a0efd543d43a3ecb3547.patch
Patch9:         https://git.sr.ht/~leon_plickat/lswt/commit/d35786da4383388c19f5437128fd393a6f16f74f.patch
Patch10:        https://git.sr.ht/~leon_plickat/lswt/commit/29329779b72cb0a7958b7491296782816de8e477.patch
Patch11:        https://git.sr.ht/~leon_plickat/lswt/commit/a39b55080dcb50edc9321d38af8775af22cf852f.patch
BuildRequires:  scdoc >= 1.9.2
BuildRequires:  pkgconfig(wayland-client)

%description
A program to list Wayland toplevels.

Requires the Wayland server to implement the foreign-toplevel-management-unstable-v1
protocol extension.

%prep
%autosetup -n %{name}-v%{version} -p1

%build
%make_build

%install
%make_install

%files
%license LICENSE
%doc README
%{_bindir}/lswt
%{_mandir}/man1/lswt.1.gz
%{_datadir}/bash-completion/completions/lswt

%changelog
* Fri Dec 13 2024 Soc Virnyl Estela <uncomfyhalomacro@opensuse.org>
- Add ea45c1a8cf66d102e6525d29b03126693949e562.patch
* Fri Dec 13 2024 Soc Virnyl Estela <uncomfyhalomacro@opensuse.org>
- Add the following patches:
  * 55a29650a110928cb7ad612182c8096424ebb70a.patch
  * 8d76a317ad2da073a638d72eac8a24df33ae01f1.patch
  * ade15dbc3d11325a2569a0efd543d43a3ecb3547.patch
  * c1ea4ee2a6e4a4e579a17f1e15351f225cb23a1d.patch
  * e4ebefcb30053a990cb821a75c4e1310fc967673.patch
  * fbb7be4354508b41552ce2159b1203db123916ac.patch
  * fdf0932f2939696a8398b63871ccc85335274c1f.patch
* Fri Dec 13 2024 Soc Virnyl Estela <uncomfyhalomacro@opensuse.org>
- Add the following patches:
  * 29329779b72cb0a7958b7491296782816de8e477.patch
  * a39b55080dcb50edc9321d38af8775af22cf852f.patch
  * d35786da4383388c19f5437128fd393a6f16f74f.patch
- Remove _service file
- Set source tarball to archived sources.
* Sat Jun  8 2024 Joshua Smith <smolsheep@opensuse.org>
- Update Makefile.patch to current Makefile
- Update to version 2.0.0:
  * Human readable output format has changed.
  * Added watch mode, which will make lswt run continously,
    printing any updates to title and app-id of all toplevels as
    they happen.
  * Added support for the new ext-foreign-toplevel-info-v1
    protocol. lswt now supports both the ext- and the old wlr-
    protocol. Note that the feature set of these protocols is not
    congruent. The new ext- protocol offers unique identifiers for
    each toplevel, which should allow greater scripting abilities,
    while the older wlr- protocol supports states such as activated
    ("focused"), minimized, maximized and fullscreen. Should the
    Wayland server support both protocols, the newer ext- protocol
    is preferred.
  * The JSON output format has changed significantly. It gained a
    field indicating it's version and a field showing which
    toplevel states supported.
  * The TSV output format has been replaced by the more common and
    more widely supported CSV output format. Fields can be
    specified using a simple format string.
  * Fixed various bugs around printing NULL values and escaping
    strings for the machine readable output formats.
  * Fixed minor memory leak.
  * The Makefile has been updated to allow building on FreeBSD more
    easily.
  * lswt can now be build with clang more easiely.
* Tue Nov  7 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Fix build with RPM 4.19: unnumbered patches are no longer
  supported.
* Mon Mar 14 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Use noun phrase in summary description
* Mon Mar 14 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Add patch to make spec simpler to build and install
* Sun Mar 13 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Fix spec (edit Version string to 1.0.4)
- Remove excluded architectures
- Clarify dependencies
* Sun Mar 13 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Use source tarball
- Update version to 1.0.4
* Sat Feb 19 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Initial rpm spec
